summaryrefslogtreecommitdiff
path: root/home
diff options
context:
space:
mode:
authorPikalaxALT <PikalaxALT@gmail.com>2015-12-26 18:11:55 -0500
committerPikalaxALT <PikalaxALT@gmail.com>2015-12-26 19:22:27 -0500
commit2bd45ca574aab251b91c24837b102c9c2a5e76a0 (patch)
treebd8c568b9e43f7467ff4822080c6228c29bca2b9 /home
parentf485a45cda5f84e6909997147b1e6c9a9a538d9b (diff)
Move effects; no more reloadmapmusic, returnafterbattle
Diffstat (limited to 'home')
-rw-r--r--home/audio.asm6
-rw-r--r--home/init.asm26
-rw-r--r--home/video.asm8
3 files changed, 20 insertions, 20 deletions
diff --git a/home/audio.asm b/home/audio.asm
index 191366d0d..63489cf68 100644
--- a/home/audio.asm
+++ b/home/audio.asm
@@ -397,7 +397,7 @@ EnterMapMusic:: ; 3d03
push af
xor a
- ld [wc2c1], a
+ ld [wDontPlayMapMusicOnReload], a
ld de, MUSIC_BICYCLE
ld a, [PlayerState]
cp PLAYER_BIKE
@@ -422,7 +422,7 @@ EnterMapMusic:: ; 3d03
; 3d2f
TryRestartMapMusic:: ; 3d2f
- ld a, [wc2c1]
+ ld a, [wDontPlayMapMusicOnReload]
and a
jr z, RestartMapMusic
xor a
@@ -431,7 +431,7 @@ TryRestartMapMusic:: ; 3d2f
call PlayMusic
call DelayFrame
xor a
- ld [wc2c1], a
+ ld [wDontPlayMapMusicOnReload], a
ret
; 3d47
diff --git a/home/init.asm b/home/init.asm
index 753138748..dacc5ff75 100644
--- a/home/init.asm
+++ b/home/init.asm
@@ -22,17 +22,17 @@ Reset:: ; 150
_Start:: ; 16e
cp $11
- jr z, .asm_175
+ jr z, .cgb
xor a
- jr .asm_177
+ jr .load
-.asm_175
+.cgb
ld a, $1
-.asm_177
+.load
ld [hCGB], a
ld a, $1
- ld [$ffea], a
+ ld [hFFEA], a
; 17d
@@ -69,29 +69,29 @@ Init:: ; 17d
ld [rLCDC], a
; Clear WRAM bank 0
- ld hl, $c000
- ld bc, $d000 - $c000
-.asm_1b1
+ ld hl, wc000
+ ld bc, wd000 - wc000
+.ByteFill
ld [hl], 0
inc hl
dec bc
ld a, b
or c
- jr nz, .asm_1b1
+ jr nz, .ByteFill
ld sp, Stack
; Clear HRAM
ld a, [hCGB]
push af
- ld a, [$ffea]
+ ld a, [hFFEA]
push af
xor a
- ld hl, $ff80
- ld bc, $ffff - $ff80
+ ld hl, HRAM_START
+ ld bc, HRAM_END - HRAM_START
call ByteFill
pop af
- ld [$ffea], a
+ ld [hFFEA], a
pop af
ld [hCGB], a
diff --git a/home/video.asm b/home/video.asm
index 15ea9b72b..96a449071 100644
--- a/home/video.asm
+++ b/home/video.asm
@@ -20,10 +20,10 @@ DMATransfer:: ; 15d8
UpdateBGMapBuffer:: ; 15e3
; Copy [$ffdc] 16x8 tiles from BGMapBuffer
; to bg map addresses in BGMapBufferPtrs.
; [$ffdc] must be even since this is done in pairs.
; Return carry on success.
@@ -76,11 +76,11 @@ rept 2
endr
; We've done 2 16x8 blocks
- ld a, [$ffdc]
+ ld a, [hFFDC]
rept 2
dec a
endr
- ld [$ffdc], a
+ ld [hFFDC], a
jr nz, .next
@@ -20,10 +20,10 @@ DMATransfer:: ; 15d8
UpdateBGMapBuffer:: ; 15e3
-; Copy [$ffdc] 16x8 tiles from BGMapBuffer
+; Copy [hFFDC] 16x8 tiles from BGMapBuffer
; to bg map addresses in BGMapBufferPtrs.
@@ -20,10 +20,10 @@ DMATransfer:: ; 15d8
; to bg map addresses in BGMapBufferPtrs.
-; [$ffdc] must be even since this is done in pairs.
+; [hFFDC] must be even since this is done in pairs.
; Return carry on success.